(function(t){function e(e){for(var n,s,i=e[0],l=e[1],u=e[2],p=0,d=[];p<i.length;p++)s=i[p],Object.prototype.hasOwnProperty.call(a,s)&&a[s]&&d.push(a[s][0]),a[s]=0;for(n in l)Object.prototype.hasOwnProperty.call(l,n)&&(t[n]=l[n]);c&&c(e);while(d.length)d.shift()();return o.push.apply(o,u||[]),r()}function r(){for(var t,e=0;e<o.length;e++){for(var r=o[e],n=!0,i=1;i<r.length;i++){var l=r[i];0!==a[l]&&(n=!1)}n&&(o.splice(e--,1),t=s(s.s=r[0]))}return t}var n={},a={embed:0},o=[];function s(e){if(n[e])return n[e].exports;var r=n[e]={i:e,l:!1,exports:{}};return t[e].call(r.exports,r,r.exports,s),r.l=!0,r.exports}s.m=t,s.c=n,s.d=function(t,e,r){s.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:r})},s.r=function(t){"undefined"!==typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},s.t=function(t,e){if(1&e&&(t=s(t)),8&e)return t;if(4&e&&"object"===typeof t&&t&&t.__esModule)return t;var r=Object.create(null);if(s.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var n in t)s.d(r,n,function(e){return t[e]}.bind(null,n));return r},s.n=function(t){var e=t&&t.__esModule?function(){return t["default"]}:function(){return t};return s.d(e,"a",e),e},s.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},s.p="/";var i=window["webpackJsonp"]=window["webpackJsonp"]||[],l=i.push.bind(i);i.push=e,i=i.slice();for(var u=0;u<i.length;u++)e(i[u]);var c=l;o.push([1,"chunk-vendors","chunk-common"]),r()})({"0611":function(t,e,r){},1:function(t,e,r){t.exports=r("8518")},"1f65":function(t,e,r){"use strict";var n=r("0611"),a=r.n(n);a.a},7195:function(t,e,r){},8518:function(t,e,r){"use strict";r.r(e);r("cadf"),r("551c"),r("f751"),r("097d");var n=r("8c4f"),a=r("2b0e"),o=r("bc3a"),s=r.n(o),i=function(){var t=this,e=t.$createElement,r=t._self._c||e;return r("div",{attrs:{id:"app"}},[r("router-view")],1)},l=[],u={name:"Embed"},c=u,p=(r("d81a"),r("2877")),d=Object(p["a"])(c,i,l,!1,null,null,null),f=d.exports,h=r("134b"),b=r.n(h),m=function(){var t=this,e=t.$createElement,r=t._self._c||e;return r("router-view-layout",[r("div",{staticClass:"box is-marginless"},[t.isLoading?r("progress",{staticClass:"progress is-small is-info"}):[t.isValid?[r("div",{staticClass:"is-grouped is-pulled-left"},[r("h3",{staticClass:"title is-5 is-inline-block mb-05r"},[t._v("\n            "+t._s(t.report.name)+"\n          ")])]),r("Chart",{attrs:{"chart-type":t.report.chartType,results:t.report.queryResults,"result-aggregates":t.report.queryResultAggregates}})]:r("div",{staticClass:"content has-text-centered"},[r("p",{staticClass:"is-italic"},[t._v(t._s(t.error))])])]],2),r("div",{staticClass:"is-pulled-right mt-05r scale-08"},[r("a",{staticClass:"is-size-7",attrs:{href:"https://meltano.com",target:"_blank"}},[r("span",{staticClass:"is-inline-block has-text-grey"},[t._v("Made with")]),r("Logo",{staticClass:"ml-05r"})],1)])])},v=[],g=r("b31f"),y=r("d706"),w=r("44ba"),_=r("5605"),O={name:"ReportEmbed",components:{Chart:g["a"],Logo:y["a"],RouterViewLayout:_["a"]},props:{token:{type:String,default:null}},data:function(){return{error:null,isLoading:!0,isValid:!1,report:null}},created:function(){this.initialize()},methods:{initialize:function(){var t=this;w["a"].loadFromEmbedToken(this.token).then((function(e){t.report=e.data,t.isValid=!0})).catch((function(e){t.error=e.response.data.code,t.isValid=!1})).finally((function(){return t.isLoading=!1}))}}},k=O,C=(r("1f65"),Object(p["a"])(k,m,v,!1,null,null,null)),j=C.exports,x=new n["a"]({mode:"history",routes:[{path:"/-/embed/:token",name:"report-embed",component:j,meta:{title:"Meltano Report Embed"},props:!0}]}),S=x,E=r("37d9");a["a"].use(n["a"]),s.a.defaults.headers.common["X-JSON-SCHEME"]="camel",a["a"].prototype.$flask=b()(),a["a"].prototype.$flask.isSendAnonymousUsageStats&&Object(E["a"])({id:"UA-132758957-6",router:S}),new a["a"]({el:"#app",router:S,render:function(t){return t(f)}})},d81a:function(t,e,r){"use strict";var n=r("7195"),a=r.n(n);a.a}});
//# sourceMappingURL=embed.ee44e827.js.map